summaryrefslogtreecommitdiff
path: root/starmath/inc/visitors.hxx
diff options
context:
space:
mode:
authorTakeshi Abe <tabe@fixedpoint.jp>2016-05-26 14:23:16 +0900
committerTakeshi Abe <tabe@fixedpoint.jp>2016-05-27 02:08:46 +0000
commit79e247d657ec400ce851c8b14500448113ee6013 (patch)
tree406dd34b126fd1df528bec94361f0e350e26323d /starmath/inc/visitors.hxx
parente10a4c1cc9f8b2033997c7f032255071aafab9c9 (diff)
starmath: Prefix members of SmSetSelectionVisitor
Change-Id: I3a5d195d65fe3a9b7b7859e3ad4c1d051628f44d Reviewed-on: https://gerrit.libreoffice.org/25491 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Takeshi Abe <tabe@fixedpoint.jp>
Diffstat (limited to 'starmath/inc/visitors.hxx')
-rw-r--r--starmath/inc/visitors.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/starmath/inc/visitors.hxx b/starmath/inc/visitors.hxx
index bbb2ff32dd0f..22816b67c312 100644
--- a/starmath/inc/visitors.hxx
+++ b/starmath/inc/visitors.hxx
@@ -255,15 +255,15 @@ private:
void DefaultVisit( SmNode* pNode ) override;
void VisitCompositionNode( SmNode* pNode );
/** Caret position where the selection starts */
- SmCaretPos StartPos;
+ SmCaretPos maStartPos;
/** Caret position where the selection ends */
- SmCaretPos EndPos;
+ SmCaretPos maEndPos;
/** The current state of this visitor
* This property changes when the visitor meets either StartPos
* or EndPos. This means that anything visited in between will be
* selected.
*/
- bool IsSelecting;
+ bool mbSelecting;
};
@@ -255,15 +255,15 @@ private:
/** The current state of this visitor
- * This property changes when the visitor meets either StartPos
- * or EndPos. This means that anything visited in between will be
+ * This property changes when the visitor meets either maStartPos
+ * or maEndPos. This means that anything visited in between will be
* selected.
*/